from icevision.parsers.parser import *

from icevision.parsers.coco_parser import *
from icevision.parsers.voc_parser import *
from icevision.parsers.via_parser import *
